@@ -1,4 +1,4 @@
-# $Id: Item.pm 588 2005-07-15 02:10:14Z claco $
+# $Id: Item.pm 597 2005-07-29 01:42:32Z claco $
 package Handel::Order::Item;
 use strict;
 use warnings;
@@ -23,6 +23,19 @@ __PACKAGE__->add_constraint('id',       id       => \&constraint_uuid);
 __PACKAGE__->add_constraint('orderid',  orderid  => \&constraint_uuid);
 __PACKAGE__->add_constraint('total',    total    => \&constraint_price);
 
+sub new {
+    my ($self, $data) = @_;
+
+    throw Handel::Exception::Argument( -details =>
+        translate('Param 1 is not a HASH reference') . '.') unless
+            ref($data) eq 'HASH';
+
+    if (!defined($data->{'id'}) || !constraint_uuid($data->{'id'})) {
+        $data->{'id'} = $self->uuid;
+    };
+
+    return $self->construct($data);
+};
 
 1;
 __END__
@@ -44,6 +57,26 @@ Handel::Order::Item - Module representing an indivudal order line item
         print $item->total;
     };
 
+=head1 CONSTRUCTOR
+
+=head2 new
+
+You can create a new C<Handel::Order::Item> object by calling the C<new> method:
+
+    my $item = Handel::Order::Item->new({
+        sku => '1234',
+        price => 1.23,
+        quantity => 1,
+        total => 1.23
+    });
+
+    $item->quantity(2);
+
+    print $item->total;
+
+This is a lazy operation. No actual item record is created until the item object
+is passed into the C<add> method of a C<Handel::Order> object.
+
 =head1 METHOS
 
 =head2 description
