@@ -1,3 +1,5 @@
+DELETE FROM orders
+DELETE FROM order_items
 INSERT INTO orders (id,shopper,type) VALUES ('11111111-1111-1111-1111-111111111111','11111111-1111-1111-1111-111111111111',0)
 INSERT INTO orders (id,shopper,type) VALUES ('22222222-2222-2222-2222-222222222222','11111111-1111-1111-1111-111111111111',1)
 INSERT INTO orders (id,shopper,type) VALUES ('33333333-3333-3333-3333-333333333333','33333333-3333-3333-3333-333333333333',1)
